#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.4.1.1
visibility:           public
id:                   pandoc-lua-engine-0.4.1.1-3jQD1DZ0vH0AbHMVbAs6BA
key:                  pandoc-lua-engine-0.4.1.1-3jQD1DZ0vH0AbHMVbAs6BA
license:              GPL-2.0-or-later
copyright:            © 2006-2024 John MacFarlane, 2017-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  290ef1ab4a6c30a2153622eaafacc1e3
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Engine
    Text.Pandoc.Lua.Filter Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Module Text.Pandoc.Lua.Marshal.Chunks
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.ImageSize
    Text.Pandoc.Lua.Marshal.LogMessage
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.Image
    Text.Pandoc.Lua.Module.JSON Text.Pandoc.Lua.Module.Log
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Run
    Text.Pandoc.Lua.SourcePos Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.4.1.1-3jQD1DZ0vH0AbHMVbAs6BA
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.3-IYlwlKn45pgAf6PDyoCVaW
    containers-0.6.7 crypton-1.0.5-ISaCEA7WOGuAiZSS5ibrwY
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    doclayout-0.5.0.2-AfbU3ODyajh57gbzmdgz7f
    doctemplates-0.11.0.1-JVCRff9KELenKRjYBPBwO exceptions-0.10.7
    hslua-2.3.1-BXkz8RACm4lJKKFZyzYPDo
    hslua-module-doclayout-1.2.0.1-JSCXUCGeQLV2bi47BBRoj8
    hslua-module-path-1.1.1-FSRNblUKZz3L1XJEGwLruJ
    hslua-module-system-1.1.3-28GgI8bUkcq1z3aQVHQyHa
    hslua-module-text-1.1.1-1HjIYsI7PckHINQqTU0qWi
    hslua-module-version-1.1.1-Jce0gSmNmgqG1reuUvVgYY
    hslua-module-zip-1.1.4-DKvHCcGuNLC88yygGufuJ4
    hslua-repl-0.1.2-1gjReql1pymCSfkmyMZDQa
    lpeg-1.1.0.1-ArLPTVmjGXs1UTKLvCuz6V mtl-2.3.1
    pandoc-3.6.1-A0xw7m9SHjA6Ws2Qavg7Fu
    pandoc-lua-marshal-0.3.1-9iS7k7J3SMT291hqKCX0jR
    pandoc-types-1.23.1.2-7r04FP2c39lATDnNYvBdb6 parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

